==========
Media App
==========

Media app is a Django app to make it easy for dealing with files (images,videos,docs and others),
Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "media_app" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'media_app',
    ]


2. Run ``python manage.py migrate`` to create the media models.



